VrmNodeConstraint class sealed

A VRMC_node_constraint on one glTF node (the destination), driven by another node (the source).

Implementers

Properties

destination → int
glTF node index the constraint moves.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → int
glTF node index it follows.
final
weight → double
0 (no effect) to 1 (full effect).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(int index, Map<String, dynamic> node, int nodeCount) → VrmNodeConstraint?
Parses the constraint on glTF node index (its nodes[index] JSON), or returns null when it has none or it is malformed.