VrmSpringCollider class

Constructors

VrmSpringCollider(int node, VrmSpringColliderShape shape)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
node → int
glTF node index the shape is attached to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → VrmSpringColliderShape
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited