VrmMeta class
meta of VRMC_vrm: who made the avatar and what it may be used for.
Properties
-
no setter
- allowExcessivelySexualUsage → bool
-
no setter
- allowExcessivelyViolentUsage → bool
-
no setter
- allowPoliticalOrReligiousUsage → bool
-
no setter
- allowRedistribution → bool
-
no setter
-
no setter
- avatarPermission → String
-
no setter
- commercialUsage → String
-
no setter
- contactInformation → String?
-
no setter
- copyrightInformation → String?
-
no setter
- creditNotation → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
json
→ Map<
String, dynamic> -
The raw
metaobject, for fields not surfaced here.final - licenseUrl → String
-
no setter
- modification → String
-
no setter
- name → String
-
no setter
- otherLicenseUrl → String?
-
no setter
-
references
→ List<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thirdPartyLicenses → String?
-
no setter
- thumbnailImage → int?
-
glTF image index of the thumbnail.
no setter
- version → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited