VrmMorphTargetBind class
A morph target weight driven by an expression.
Constructors
- VrmMorphTargetBind(int node, int index, double weight)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Morph target index within that mesh.
final
- node → int
-
glTF node index (the node carrying the mesh).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weight → double
-
Weight at expression value 1.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited